==> klass-compiler-0.2.0-sources.jar: cool/klass/model/converter/compiler/state/projection/AntlrProjectionElement.java <==
/*
 * Copyright 2024 Craig Motlin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cool.klass.model.converter.compiler.state.projection;

import java.util.Optional;

import javax.annotation.Nonnull;

import cool.klass.model.converter.compiler.annotation.CompilerAnnotationHolder;
import cool.klass.model.converter.compiler.state.IAntlrElement;
import cool.klass.model.meta.domain.projection.AbstractProjectionElement.ProjectionElementBuilder;

public interface AntlrProjectionElement
        extends IAntlrElement
{
    @Nonnull
    ProjectionElementBuilder build();

    void build2();

    void visit(@Nonnull AntlrProjectionVisitor visitor);

    @Nonnull
    AntlrProjectionParent getParent();

    @Nonnull
    @Override
    default Optional<IAntlrElement> getSurroundingElement()
    {
        return Optional.of(this.getParent());
    }

    @Nonnull
    String getName();

    void reportErrors(@Nonnull CompilerAnnotationHolder compilerAnnotationHolder);

    void reportDuplicateMemberName(@Nonnull CompilerAnnotationHolder compilerAnnotationHolder);
}

==> klass-compiler-0.5.0-sources.jar: cool/klass/model/converter/compiler/state/projection/AntlrProjectionElement.java <==
/*
 * Copyright 2024 Craig Motlin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cool.klass.model.converter.compiler.state.projection;

import java.util.Optional;

import javax.annotation.Nonnull;

import cool.klass.model.converter.compiler.annotation.CompilerAnnotationHolder;
import cool.klass.model.converter.compiler.state.IAntlrElement;
import cool.klass.model.meta.domain.projection.AbstractProjectionElement.ProjectionElementBuilder;

public interface AntlrProjectionElement extends IAntlrElement {
    @Nonnull
    ProjectionElementBuilder build();

    void build2();

    void visit(@Nonnull AntlrProjectionVisitor visitor);

    @Nonnull
    AntlrProjectionParent getParent();

    @Nonnull
    @Override
    default Optional<IAntlrElement> getSurroundingElement() {
        return Optional.of(this.getParent());
    }

    @Nonnull
    String getName();

    void reportErrors(@Nonnull CompilerAnnotationHolder compilerAnnotationHolder);

    void reportDuplicateMemberName(@Nonnull CompilerAnnotationHolder compilerAnnotationHolder);
}
